@@ -207,7 +207,12 @@ PAlist = {
         "Vauban": "Akstiletto,Fragor",
         "Volt": "Odonata",
         "Wukong": "Ninkondi,Zhuge",
-        "Zephyr": "Kronen,Tiberon"
+        "Zephyr": "Kronen,Tiberon",
+        "Harrow": "Knell,Scourge",
+        "Garuda": "Corvas,Nangantaka",
+        "Khora": "Hystrix,Dual Keres",
+        "Revenant": "Phantasma,Tatsu",
+        "Baruuk": "Afuris,Cobra & Crane"
     }
 }
 
@@ -400,8 +405,8 @@ def build_json_files(pd_file=None):
 
 def get_price_data(pd_file):
     if pd_file is None:
-        soup = BeautifulSoup(requests.get('http://23.95.43.245/history/').text, 'html.parser')
-        return requests.get(sorted(['http://23.95.43.245/history/' + node.get('href')
+        soup = BeautifulSoup(requests.get('http://198.46.233.213/history/').text, 'html.parser')
+        return requests.get(sorted(['http://198.46.233.213/history/' + node.get('href')
                                     for node in soup.find_all('a') if node.get('href').endswith('json')])[-1]).json()
     else:
-        return requests.get(f"http://23.95.43.245/history/{pd_file}").json()
\ No newline at end of file
+        return requests.get(f"http://198.46.233.213/history/{pd_file}").json()
